/*******************************************************************************
* File Name: EXT.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "EXT.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 EXT__PORT == 15 && ((EXT__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: EXT_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void EXT_Write(uint8 value) 
{
    uint8 staticBits = (EXT_DR & (uint8)(~EXT_MASK));
    EXT_DR = staticBits | ((uint8)(value << EXT_SHIFT) & EXT_MASK);
}


/*******************************************************************************
* Function Name: EXT_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void EXT_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(EXT_0, mode);
}


/*******************************************************************************
* Function Name: EXT_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro EXT_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 EXT_Read(void) 
{
    return (EXT_PS & EXT_MASK) >> EXT_SHIFT;
}


/*******************************************************************************
* Function Name: EXT_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 EXT_ReadDataReg(void) 
{
    return (EXT_DR & EXT_MASK) >> EXT_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(EXT_INTSTAT) 

    /*******************************************************************************
    * Function Name: EXT_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 EXT_ClearInterrupt(void) 
    {
        return (EXT_INTSTAT & EXT_MASK) >> EXT_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
