/*******************************************************************************
* File Name: INT_K.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "INT_K.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 INT_K__PORT == 15 && ((INT_K__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: INT_K_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void INT_K_Write(uint8 value) 
{
    uint8 staticBits = (INT_K_DR & (uint8)(~INT_K_MASK));
    INT_K_DR = staticBits | ((uint8)(value << INT_K_SHIFT) & INT_K_MASK);
}


/*******************************************************************************
* Function Name: INT_K_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void INT_K_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(INT_K_0, mode);
}


/*******************************************************************************
* Function Name: INT_K_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro INT_K_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 INT_K_Read(void) 
{
    return (INT_K_PS & INT_K_MASK) >> INT_K_SHIFT;
}


/*******************************************************************************
* Function Name: INT_K_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 INT_K_ReadDataReg(void) 
{
    return (INT_K_DR & INT_K_MASK) >> INT_K_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(INT_K_INTSTAT) 

    /*******************************************************************************
    * Function Name: INT_K_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 INT_K_ClearInterrupt(void) 
    {
        return (INT_K_INTSTAT & INT_K_MASK) >> INT_K_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
