/*******************************************************************************
* File Name: I_SDO.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "I_SDO.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 I_SDO__PORT == 15 && ((I_SDO__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: I_SDO_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void I_SDO_Write(uint8 value) 
{
    uint8 staticBits = (I_SDO_DR & (uint8)(~I_SDO_MASK));
    I_SDO_DR = staticBits | ((uint8)(value << I_SDO_SHIFT) & I_SDO_MASK);
}


/*******************************************************************************
* Function Name: I_SDO_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void I_SDO_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(I_SDO_0, mode);
}


/*******************************************************************************
* Function Name: I_SDO_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro I_SDO_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 I_SDO_Read(void) 
{
    return (I_SDO_PS & I_SDO_MASK) >> I_SDO_SHIFT;
}


/*******************************************************************************
* Function Name: I_SDO_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 I_SDO_ReadDataReg(void) 
{
    return (I_SDO_DR & I_SDO_MASK) >> I_SDO_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(I_SDO_INTSTAT) 

    /*******************************************************************************
    * Function Name: I_SDO_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 I_SDO_ClearInterrupt(void) 
    {
        return (I_SDO_INTSTAT & I_SDO_MASK) >> I_SDO_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
