/*******************************************************************************
* File Name: MOK_US.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "MOK_US.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 MOK_US__PORT == 15 && ((MOK_US__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: MOK_US_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void MOK_US_Write(uint8 value) 
{
    uint8 staticBits = (MOK_US_DR & (uint8)(~MOK_US_MASK));
    MOK_US_DR = staticBits | ((uint8)(value << MOK_US_SHIFT) & MOK_US_MASK);
}


/*******************************************************************************
* Function Name: MOK_US_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void MOK_US_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(MOK_US_0, mode);
}


/*******************************************************************************
* Function Name: MOK_US_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro MOK_US_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 MOK_US_Read(void) 
{
    return (MOK_US_PS & MOK_US_MASK) >> MOK_US_SHIFT;
}


/*******************************************************************************
* Function Name: MOK_US_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 MOK_US_ReadDataReg(void) 
{
    return (MOK_US_DR & MOK_US_MASK) >> MOK_US_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(MOK_US_INTSTAT) 

    /*******************************************************************************
    * Function Name: MOK_US_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 MOK_US_ClearInterrupt(void) 
    {
        return (MOK_US_INTSTAT & MOK_US_MASK) >> MOK_US_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
