/*******************************************************************************
* File Name: MOK_WATER.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "MOK_WATER.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 MOK_WATER__PORT == 15 && ((MOK_WATER__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: MOK_WATER_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void MOK_WATER_Write(uint8 value) 
{
    uint8 staticBits = (MOK_WATER_DR & (uint8)(~MOK_WATER_MASK));
    MOK_WATER_DR = staticBits | ((uint8)(value << MOK_WATER_SHIFT) & MOK_WATER_MASK);
}


/*******************************************************************************
* Function Name: MOK_WATER_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void MOK_WATER_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(MOK_WATER_0, mode);
}


/*******************************************************************************
* Function Name: MOK_WATER_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro MOK_WATER_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 MOK_WATER_Read(void) 
{
    return (MOK_WATER_PS & MOK_WATER_MASK) >> MOK_WATER_SHIFT;
}


/*******************************************************************************
* Function Name: MOK_WATER_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 MOK_WATER_ReadDataReg(void) 
{
    return (MOK_WATER_DR & MOK_WATER_MASK) >> MOK_WATER_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(MOK_WATER_INTSTAT) 

    /*******************************************************************************
    * Function Name: MOK_WATER_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 MOK_WATER_ClearInterrupt(void) 
    {
        return (MOK_WATER_INTSTAT & MOK_WATER_MASK) >> MOK_WATER_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
