/*******************************************************************************
* File Name: PWR5.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "PWR5.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 PWR5__PORT == 15 && ((PWR5__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: PWR5_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void PWR5_Write(uint8 value) 
{
    uint8 staticBits = (PWR5_DR & (uint8)(~PWR5_MASK));
    PWR5_DR = staticBits | ((uint8)(value << PWR5_SHIFT) & PWR5_MASK);
}


/*******************************************************************************
* Function Name: PWR5_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void PWR5_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(PWR5_0, mode);
}


/*******************************************************************************
* Function Name: PWR5_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro PWR5_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 PWR5_Read(void) 
{
    return (PWR5_PS & PWR5_MASK) >> PWR5_SHIFT;
}


/*******************************************************************************
* Function Name: PWR5_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 PWR5_ReadDataReg(void) 
{
    return (PWR5_DR & PWR5_MASK) >> PWR5_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(PWR5_INTSTAT) 

    /*******************************************************************************
    * Function Name: PWR5_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 PWR5_ClearInterrupt(void) 
    {
        return (PWR5_INTSTAT & PWR5_MASK) >> PWR5_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
