/*******************************************************************************
* File Name: Status_KeyBoard.c  
* Version 1.80
*
* Description:
*  This file contains API to enable firmware to read the value of a Status 
*  Register.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "Status_KeyBoard.h"

#if !defined(Status_KeyBoard_sts_sts_reg__REMOVED) /* Check for removal by optimization */


/*******************************************************************************
* Function Name: Status_KeyBoard_Read
********************************************************************************
*
* Summary:
*  Reads the current value assigned to the Status Register.
*
* Parameters:
*  None.
*
* Return:
*  The current value in the Status Register.
*
*******************************************************************************/
uint8 Status_KeyBoard_Read(void) 
{ 
    return Status_KeyBoard_Status;
}


/*******************************************************************************
* Function Name: Status_KeyBoard_InterruptEnable
********************************************************************************
*
* Summary:
*  Enables the Status Register interrupt.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void Status_KeyBoard_InterruptEnable(void) 
{
    uint8 interruptState;
    interruptState = CyEnterCriticalSection();
    Status_KeyBoard_Status_Aux_Ctrl |= Status_KeyBoard_STATUS_INTR_ENBL;
    CyExitCriticalSection(interruptState);
}


/*******************************************************************************
* Function Name: Status_KeyBoard_InterruptDisable
********************************************************************************
*
* Summary:
*  Disables the Status Register interrupt.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void Status_KeyBoard_InterruptDisable(void) 
{
    uint8 interruptState;
    interruptState = CyEnterCriticalSection();
    Status_KeyBoard_Status_Aux_Ctrl &= (uint8)(~Status_KeyBoard_STATUS_INTR_ENBL);
    CyExitCriticalSection(interruptState);
}


/*******************************************************************************
* Function Name: Status_KeyBoard_WriteMask
********************************************************************************
*
* Summary:
*  Writes the current mask value assigned to the Status Register.
*
* Parameters:
*  mask:  Value to write into the mask register.
*
* Return:
*  None.
*
*******************************************************************************/
void Status_KeyBoard_WriteMask(uint8 mask) 
{
    #if(Status_KeyBoard_INPUTS < 8u)
    	mask &= (uint8)((((uint8)1u) << Status_KeyBoard_INPUTS) - 1u);
	#endif /* End Status_KeyBoard_INPUTS < 8u */
    Status_KeyBoard_Status_Mask = mask;
}


/*******************************************************************************
* Function Name: Status_KeyBoard_ReadMask
********************************************************************************
*
* Summary:
*  Reads the current interrupt mask assigned to the Status Register.
*
* Parameters:
*  None.
*
* Return:
*  The value of the interrupt mask of the Status Register.
*
*******************************************************************************/
uint8 Status_KeyBoard_ReadMask(void) 
{
    return Status_KeyBoard_Status_Mask;
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
