/*******************************************************************************
* File Name: VHALF.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "VHALF.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 VHALF__PORT == 15 && ((VHALF__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: VHALF_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void VHALF_Write(uint8 value) 
{
    uint8 staticBits = (VHALF_DR & (uint8)(~VHALF_MASK));
    VHALF_DR = staticBits | ((uint8)(value << VHALF_SHIFT) & VHALF_MASK);
}


/*******************************************************************************
* Function Name: VHALF_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void VHALF_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(VHALF_0, mode);
}


/*******************************************************************************
* Function Name: VHALF_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro VHALF_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 VHALF_Read(void) 
{
    return (VHALF_PS & VHALF_MASK) >> VHALF_SHIFT;
}


/*******************************************************************************
* Function Name: VHALF_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 VHALF_ReadDataReg(void) 
{
    return (VHALF_DR & VHALF_MASK) >> VHALF_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(VHALF_INTSTAT) 

    /*******************************************************************************
    * Function Name: VHALF_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 VHALF_ClearInterrupt(void) 
    {
        return (VHALF_INTSTAT & VHALF_MASK) >> VHALF_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
