/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#ifndef DEFINITION_H
#define DEFINITION_H
#include <project.h>
#include <cytypes.h>
	
//---------------------------------------------------------------------
//Constant Definitions
//---------------------------------------------------------------------
// modifica per US

/* specifiche 1  corrente + 9 programmi memorizzati */
#define EXEC         0			// Array index for segment1 EXEC
#define	DEGRES       1			// Array index for segment1 DEGRES
#define	TIMER        2			// Array index for segment1 TIMER
#define	USPOWER      3			// Array index for segment1 USPOWER

/* specifiche costanti di regolazione controlli  */
#define	MODEL_TANK   0			// Array index for segment2 MODEL_TANK
#define	UPTIME	     7			// Array index for segment2 UPTIME
#define PWR_MAX      8          // Array segment2 PWR_MAX
#define FIRST        12         // marker di prima accensione

/* microprocessor constant */
#define MAX_TIMING   100000     // ADC timeout
#define	NUMBER_ACQ	 16         // number of acquisition
#define N_ADC_SHIFT	 4			// 16 -> 4^2	
#define	ADC0_GAIN    1			// Constant ADC0 sensitivity
#define	ADC1_G100    8			// Constant ADC1 sensitivity (12)
#define	ADC1_G200    4			// Constant ADC1 sensitivity (8)
#define	ADC1_G300    3			// Constant ADC1 sensitivity (5)
#define	ADC1_G400    2			// Constant ADC1 sensitivity (4)
#define	ADC2_GAIN    1			// Constant ADC2 sensitivity
#define SCALE_G100   140		// scale to display sonox 9
#define SCALE_G200   130		// scale to display sonox 14
#define SCALE_G300   110		// scale to display sonox 20	
#define SCALE_G400   85 		// scale to display sonox 28
#define SCALE_OVER   20 		// over scale for > pwr_max
#define COEFF_VDAC_TO_POWER     0.45

/* digit display  */
#define	VALUE_PROG   0x85  		// Send to ADDRESS LCD value PROGR ":" POSITION
#define	VALUE_PWR    0x8b  		// Send to ADDRESS LCD value PWR   ":" POSITION
#define	VALUE_TEMP   0xc2  		// Send to ADDRESS LCD value HT ":" POSITION
#define	VALUE_TIME   0xcc  		// Send to ADDRESS LCD value TIME ":" POSITION

	
/* pagine di memoria EEPROM */
#define	PAGE_SEG1    5     		// n° page (16 bytes) row segment1  
#define	PAGE_SEG2    2     		// n° page (16 bytes) row segment2  
#define NUM_BYTES    16			// bytes for row
#define NUM_ROW1     10         // righe segmento 1      nr programmi
#define NUM_COL1     4          // colonne segmento 1	 nr variabili per programma
#define NUM_ROW2     1          // righe segmento 2      nr page general operating parameter
#define NUM_COL2     13         // colonne segmento 2    nr parameter
	
/* valori limite regolazioni e temporizzazioni */
#define DELAY_INIT   20                 // Delay iniziale in msec
                                        // attenzione a multipli di 100 e 101
#define	RAMP	     3          		// Constant RAMP step by tick
#define TIME_PROT    200  				// temporizzazione protezione
 
/* definizione keyboard */
#define	P_EXEC	     0					// PB0 KEY
#define	P_DEGRES     1					// PB1 KEY
#define	P_USPOWER    2					// PB2 KEY
#define	P_TIMER	     3					// PB3 KEY
#define	START_STOP   4     				// PB4 KEY
#define	PAUSE_ENTER  5   				// PB5 KEY
#define	P_UP	     6		        	// PB6 KEY
#define	P_DOWN       7		        	// PB7 KEY
#define P_DEGASS     8                  // PB8 combinazione
#define P_NONE       9                  // no key pressed
#define P_FAST_US    10                 // fast US key pressed
#define P_FAST_DG    11                 // fast DG key pressed

/* livelli di intervento protezioni */
#define	CUR_LOADLOW  10  		// Constant for detect low load % 
#define	CUR_LOADHIGH 700		// Constant for detect high load % (divide /2)
#define	CURR_LIM_MAX 950		// Constant for detect power limit
#define	DEGRESLIM    98 		// Constant DEGRESLIM  in °C
#define	PWM_MAXDG    486	    // Constant PWM max duty cycle 512 * 95% ( 1sec period)
#define	PWM_MINUS    3                  // Constant PWM min duty cycle NEAR 0
#define	PWM_MINDG    25		        // Constant PWM min duty cycle 512 * 5%
#define	PWM_OFFDG    153		// Constant PWM offset ( feedforward ) 512 * xx%

/* valori default ad accensione , saranno sovrascritti */
#define UPDATE_DG      512              // Constant default UPDATE_DG tick 2 msec
#define UPTIME_DF      44000            // Constant default UPTIME tick 2 msec
#define KP_DGPWR_DF    10               // Constant default KP_DGPOWER_DF
#define KD_DGPWR_DF    0                // Constant default KD_DGPOWER_DF
#define KF_DGPWR_DF    10               // Constant default KF_DGPOWER_DF
#define NUM_CHAR       32               // Total char into LCD (2x16)
   
/* valori tick scan keyboard */
// dispari o pari per evitare sovrapposizioni di routine in interupt 
#define KEY_MIN_TIME   60              // key_min_time * time refresh [dispari]
#define KEYTIME        4               // decremento del tempo di refresh tasti UP & DOWN[pari]
#define UPDATE_KEY     360             // update_key * time refresh (update dei tasti)[dispari]

//---------------------------------------------------------------------
// constant array declarations US GENERATOR
//---------------------------------------------------------------------

extern const char mask[];
extern const char name[];
extern const char model0[] ;
extern const char model1[] ;
extern const char model2[] ;
extern const char model3[] ;
extern const char model[] ;
extern const char degass[]; 
extern const char tank_prot[] ;
extern const char gen_prot[];
extern const char ready[];
extern const char error[];
extern const int  thermistor[]; 

// Lookup Table 0 - 100 °C Rserie 270 Rtherm = 870 Ris = 10bit 3% PRECISIONE
extern const int level_pwm[];   

// Lookup Table 1 - 40 level_power = level_pwm[entry_table] / 256 * c_power
extern char strbuffer[NUM_CHAR];        // buffer di transizione rom to display
extern char inpbuf[8];			// Input command buffer
extern char outputf[8];			// Output USART buffer
extern char ascii[7] ;                  // buffer for LCD values

extern uint32 update_timerID_Main,update_timerID_Minutes,update_timerID_Keyboard ;
extern uint8
segnum,					// Current executing segment
parameter,				// Index to profile data
i,						// index to ASCII buffer
step_Up,step_Down,                      // step key UP & DOWN values      
blank,                                  // registri a 1 byte   
j,
c_key,Prog_Func,
k,first0,channel,
scan_calc,datain,
w,scan_display,
ii,jj,table_entry
;

//extern unsigned char
//TEMPB1;

extern double
Float_1stmulti,Float_2stmulti,
Float_product,Float_dividend,Float_divisor,
Float_quotient,Float_USScale,Float_InverseUSScale,
Float_Scale,Float_over,
view_100,view_200,view_300,view_400
;
 
//typedef struct {
//    uint32 	   e_StartUs:1;		// Enable start ciclo
//    uint32 	   e_Enter:1;		// Enter command  
//    uint32 	   e_Press:1;		// Press key flag    
//    uint32     f_LoadLow:1;     // flag di carico basso (poco liquido)
//    uint32     f_LoadHigh:1;    // flag di carico alto  (oggetto su fondo)
//    uint32 	   f_HighPwr:1;		// flag di overheating TRIAC & IGBT
//    uint32 	   pwmSatUs:1;	    // flag di saturazione pwm US
//    uint32 	   pwmSatDg:1;	    // flag di saturazione pwm DG
//    uint32 	   pwr_max:1;	    // flag di over power limit US
//    uint32 	   curr_max:1;	    // flag di over current limit US
//    uint32     f_HighTemp:1;    // flag di over temperature HEATER
//    uint32     e_StartPwr:1;   	// flag di abilitazione main power
//    uint32     e_Read:1;		// flag di acquisizione measure
//    uint32     e_aux:1;   		// flag di intervento esterno
//    uint32     e_extStart:1;   	// flag di start/stop esterno
//    uint32     e_ADC:1;
//    uint32     e_ScanCalc:1;
//    uint32     e_degass:1;
//    uint32     e_pulse:1;
//    uint32     e_First_Acq:1;
//    uint32     e_First_Sync:1;
//    uint32     e_display:1;
//    uint32     e_View:1;
//    uint32     e_P_UP:1;      	// flag pressione P_UP
//    uint32     e_P_DN:1;     	// flag pressione P_DOWN
//    uint32     e_simple:1;    	// flag "simple start"
//    uint32     eFastUs:1;
//    uint32     eFastDg:1;
//    uint32     eSSPress:1;
//    uint32     eDGPress:1;
//    uint32     eFastKey:1;
//    uint32     eInterEna:1;  	// sincronizzazione gestione interupt
//    uint32     e_Fault:1;
//    uint32     e_correct_view:1;// view correct power value
//} stat_DEF ;
typedef struct {
    uint8 	  e_StartUs;		// Enable start ciclo
    uint8 	  e_Enter;			// Enter command  
    uint8 	  e_Press;			// Press key flag    
    uint8     f_LoadLow;     	// flag di carico basso (poco liquido)
    uint8     f_LoadHigh;    	// flag di carico alto  (oggetto su fondo)
    uint8 	  f_HighPwr;		// flag di overheating TRIAC & IGBT
    uint8 	  pwmSatUs;	    	// flag di saturazione pwm US
    uint8 	  pwmSatDg;	    	// flag di saturazione pwm DG
    uint8 	  pwr_max;	    	// flag di over power limit US
    uint8 	  curr_max;	    	// flag di over current limit US
    uint8     f_HighTemp;    	// flag di over temperature HEATER
    uint8     e_StartPwr;   	// flag di abilitazione main power
    uint8     e_Read;			// flag di acquisizione measure
    uint8     e_aux;   			// flag di intervento esterno
    uint8     e_extStart;   	// flag di start/stop esterno
    uint8     e_ADC;
    uint8     e_ScanCalc;
    uint8     e_degass;
    uint8     e_pulse;
    uint8     e_First_Acq;
    uint8     e_First_Sync;
    uint8     e_display;
    uint8     e_View;
    uint8     e_P_UP;      	// flag pressione P_UP
    uint8     e_P_DN;     	// flag pressione P_DOWN
    uint8     e_simple;    	// flag "simple start"
    uint8     eFastUs;
    uint8     eFastDg;
    uint8     eSSPress;
    uint8     eDGPress;
    uint8     eFastKey;
    uint8     eInterEna;  	// sincronizzazione gestione interupt
    uint8     e_Fault;
    uint8     e_correct_view;// view correct power value
} stat_DEF ;
extern stat_DEF stat ;
extern uint8 button,debug ;
// DMA setting
/* Variable declarations for DMA_Current */
extern uint8 DMA_Current_Chan;
extern uint8 DMA_Current_TD[1];
/* Variable declarations for DMA_Therm */
extern uint8 DMA_Therm_Chan;
extern uint8 DMA_Therm_TD[1];
/* DMA Configuration for DMA_Current */
#define DMA_Current_BYTES_PER_BURST 2
#define DMA_Current_REQUEST_PER_BURST 1
#define DMA_Current_SRC_BASE (CYDEV_PERIPH_BASE)
#define DMA_Current_DST_BASE (CYDEV_SRAM_BASE)
/* DMA Configuration for DMA_Therm */
#define DMA_Therm_BYTES_PER_BURST 2
#define DMA_Therm_REQUEST_PER_BURST 1
#define DMA_Therm_SRC_BASE (CYDEV_PERIPH_BASE)
#define DMA_Therm_DST_BASE (CYDEV_SRAM_BASE)

extern uint16 current[16],therm[16];

extern int16 *usegm  ;                               // pointer utag.xxx 	

extern  uint16 U_value,Norm_power,Norm_degres,Timer_degres,
m_power,m_current,m_volt,m_degres,over_power,show_power,
prot_current,m_timer,                                // Measured values
c_power,c_timer,c_tank,c_degres,c_exec,p_value,      // Commanded values
kpDg,kfDg,kdDg,                         			// DG PID gain constants
curr_max,pwr_max,curLoad_low,curLoad_high,          // valori massimi attuali
minutes,											// counter minutes
half_second,										// counter 1/2 second from pwm degres
m_Npower,m_Ndegres,
t0_Npower,t0_current,t0_Ndegres,
t0_c_exec,t0_d_degres,t0_d_timer,t0_d_power,
pwm_limitmaxUs,
pwm_USValue,pwm_limitmaxDg,             			// max value pwm
pwm_limitminUs,pwm_limitminDg,         				// min value pwm
pwm_offsetUs,		                				// pwm offset (1/2 scale)
updateRamp,			                  				// conteggio tick ad ogni interupt (2 msec)
ref_power,			        						// real value commamded US power
d_exec,d_degres,d_timer,d_power,        			// registri per cifre display
PBkey,
initial,  											// delay iniziale
calc_duty,											// calcola duty cycle da c_freq 
updateKey,KeyTick,
n_bytes,n_pages,data0,data1,data2,address,
Norm_PwrMax,updatePulse,
adc1_gain,acq_degres,ram_degres,
*therm_rom,                             // pointer lookup table thermistor
therm_ram_data,temp_time,pwm_data,
updateView,updateProt,filterProt,ram_duty,entry_table
;

extern int32 updateTick,read_measure,L_value;
typedef union			
{
int32 l;
uint32 ul;
int16 i[2];
int16 j[2];
uint16 ui[2];
int8 b[4];
uint8 ub[4];
}LNG;

extern LNG temp,u0,u3,u2,u1,u4,ypid,math_result;

 typedef union 
{
unsigned int t;
unsigned char byte[2];
}INT2;

extern INT2 transfer,FU_value,operand1,operand2,ADCReg,PID_temp,int_u0,int_u1,int_u2,
			int_u3,second_tick,c_uptime ;
extern int16 segment1[NUM_ROW1][NUM_COL1];   // Holds program segment values in data memory.
extern int16 segment2[NUM_ROW2][NUM_COL2];

//---------------------------------------------------------------------
// Function Prototypes US GENERATOR
//---------------------------------------------------------------------

/* GENERAL */
void servo_isr(void);		        	// Does servo calculations
void InitEEPROM(void) ;                 // Initialized EEPROM
void Calculation(void) ;


/* MATH  */
void ScaleFloat(void)  ;				// precalculation float division Scale factor

/* US POWER */
void CalcUsPower(void);                 // Calcolo potenza da VLEVEL,ILEVEL
void power_USCommand(void);

/* DEGRES POWER */
//void First_ACQ_Degres(void) ;
//void Cont_ACQ_Degres(void) ;
void Simple_DGError(void) ;
void Simple_DGPid(void) ;

/* GENERAL  */
void SysProtAll(void);                  // controllo generale sistema
void Setup(void);		        // Configures peripherals and variables
void SetProg(unsigned char);	      	// setta i programmi da eseguire
void CallDegass(void);                  // abilitazione degass
void ResetFlag(void);                   // Reset all flag stat.xx
void ControlRange(void) ;               // ceck values in useful range
void ControlMeasure(void) ;             // ceck misurated values in useful range
void Acquire(void) ;                    // acquire input signal
void therm_ram(const int *therm) ;  // lettura lookup table termistor
void Read_Table(const int *therm) ;
void pwm_ram(const int *therm) ;	// lettura lookup table level_pwm
void view_Temperature(void);          
void itoa(unsigned int value,char *buffer);
void CyDmaChEnable_FIX(uint8 DMA_Channel);
void ADC_dma_release(void);
void ADC_dma_enable(void);
void DMA_init(void);


/* GESTIONE TIMER */
void CalcMinutes(void);	          	// gestione timer


/* GESTIONE EEPROM  A PAGINE */
void EEWrite(void);
void EERead(void);

/* GESTIONE LCD chip */
void LcdInit(void) ;                             // init LCD
void LcdOn(void) ;
void LcdBlank(unsigned char data) ;
void LcdNOBlank(unsigned char data) ;
void LcdDisplayMode(unsigned char data);
void LcdClear(void) ;
void LcdHome(void) ;
void MORONI_LCD_Char_1_PrintString(char8 const string[]) ;
uint8 test_KeyBoard(uint8 column);
#endif
/* [] END OF FILE */
